@@ -4,9 +4,9 @@ use criterion::{criterion_group, criterion_main, Criterion};
 use crossterm::execute;
 use crossterm::terminal as term;
 use std::fs;
-use termion::get_tty;
 use tui::backend::CrosstermBackend;
 use tui::Terminal;
+use xplr::runner::get_tty;
 use xplr::*;
 
 const PWD: &str = "/tmp/xplr_bench";
