@@ -453,8 +453,10 @@ fn draw_table<B: Backend>(
                 .map(|(index, node)| {
                     let is_focused = dir.focus() == index;
 
-                    // TODO : Optimize
-                    let is_selected = app.selection().contains(node);
+                    let is_selected = app
+                        .selection()
+                        .iter()
+                        .any(|s| s.absolute_path == node.absolute_path);
 
                     let is_first = index == 0;
                     let is_last = index == dir.total().max(1) - 1;
@@ -536,7 +538,7 @@ fn draw_table<B: Backend>(
                     };
 
                     let meta = NodeUiMetadata::new(
-                        &node,
+                        node,
                         index,
                         relative_index,
                         is_before_focus,
@@ -788,7 +790,7 @@ fn draw_sort_n_filter<B: Backend>(
         .iter()
         .map(|f| {
             ui.filter_identifiers()
-                .get(&f.filter())
+                .get(f.filter())
                 .map(|u| {
                     let ui = defaultui.to_owned().extend(u);
                     (
@@ -805,7 +807,7 @@ fn draw_sort_n_filter<B: Backend>(
             let direction = if s.reverse() { &reverseui } else { &forwardui };
 
             ui.sorter_identifiers()
-                .get(&s.sorter())
+                .get(s.sorter())
                 .map(|u| {
                     let ui = defaultui.to_owned().extend(u);
                     (
@@ -857,7 +859,7 @@ fn draw_logs<B: Backend>(
         app.logs()
             .iter()
             .rev()
-            .take(1)
+            .take(layout_size.height as usize)
             .rev()
             .map(|l| {
                 let time = l.created_at().format("%r");
